Amatino Python
==============

Amatino is a double entry accounting system. It provides double entry
accounting as a service. Amatino is served via a web API. Amatino
Python is a library for interacting with the Amatino API from within a
Python application. By using Amatino Python, a Python developer can
utilise Amatino services without needing to deal with raw HTTP
requests.

Under Construction
------------------

Amatino Python is in a pre-alpha state. It is not yet ready for public
use and should not be used by anyone for anything.

To be notified when Amatino Python enters an alpha state, ready for
consumption, sign up to the Amatino Development Newsletter, available
at <https://amatino.io/newsletter/>.

In the mean time, you may wish to review Amatino's HTTP documentation
at <https://amatino.io/documentation/http>, to see what capabilities
you can expect from Amatino Python in future.

Installation
------------

Amatino Python may be installed via ``pip`::

    $ pip install amatino
